@@ -6,7 +6,7 @@ from jupyter_server.base.handlers import APIHandler
 from jupyter_server.utils import url_path_join
 
 
-class DatalayerHandler(APIHandler):
+class JupyterRtcHandler(APIHandler):
 
     # The following decorator should be present on all verb methods (head, get, post,
     # patch, put, delete, options) to ensure only authorized user can request the Jupyter server
@@ -21,5 +21,5 @@ def setup_handlers(web_app):
     host_pattern = ".*$"
     base_url = web_app.settings["base_url"]
     route_pattern = url_path_join(base_url, "jupyter_rtc", "get_example")
-    handlers = [(route_pattern, DatalayerHandler)]
+    handlers = [(route_pattern, JupyterRtcHandler)]
     web_app.add_handlers(host_pattern, handlers)
